# -*- coding: utf-8 -*-
import datetime
from reportserver.lib.db.report_dal import retrieve_report_data
from reportserver.lib.report.esfreport import EsfReport


def create_report_for(programname, filters):
    """
    Generates Report (Durchführungsbericht)
    :param programname: WASKIQ|PWE|SIB|EC
    :param start_date:
    :param end_date:
    :return: EsfReport object
    """
    rows = retrieve_report_data(filters, programname)
    return EsfReport(programname, rows)


def get_start_date(date):
    """
    gets start date in german format
    if no date is set, the first day of the current year is taken
    :param date:
    :return:
    """
    if not date:
        return convert_to_german_date(datetime.date(
            datetime.date.today().year, 1, 1))
    return convert_to_german_date(date)


def get_end_date(date):
    """
    gets end date in german format
    if no date is set, the last day of the current year is taken
    :param date:
    :return:
    """
    if not date:
        return convert_to_german_date(datetime.date(
            datetime.date.today().year, 12, 31))
    return convert_to_german_date(date)


def convert_to_german_date(date):
    """
    converts date to german format
    :param date:
    :return:
    """
    return date.strftime("%d.%m.%Y")
